# punpy: Propagating Uncertainties with PYthon

**punpy** is a Python software package to propagate random, structured and systematic uncertainties through a given measurement function.

punpy is part of the [CoMet Toolkit](https://www.comet-toolkit.org) (community metrology toolkit), and can combined with the [obsarray](https://obsarray.readthedocs.io/en/latest/) (Measurement uncertainty handling in Python) for efficient definition, storing and interfacing with uncertainty information using standardised metadata.

## Installation

punpy is installable via pip.

## Documentation

For more information visit our [documentation](https://punpy.readthedocs.io/en/latest).

## License

punpy is free software licensed under the
[GNU Public License (v3)](./LICENSE).

## Acknowledgements

punpy has been developed by [Pieter De Vis](https://www.comet-toolkit.org/author/pieter-de-vis/).

The development has been funded by:

* The UK's Department for Business, Energy and Industrial Strategy's (BEIS) National Measurement System (NMS) programme
* The IDEAS-QA4EO project funded by the European Space Agency.

## Project status

punpy is under active development. It is beta software.

